@@ -4,6 +4,7 @@ from typing import Optional, Callable
 
 RandImageFunc = Optional[Callable[[np.ndarray], np.ndarray]]
 _f_randomize_rgb_image: RandImageFunc = None
+_f_randomize_gray_image: RandImageFunc = None
 _f_randomize_depth_image: RandImageFunc = None
 
 
@@ -20,6 +21,17 @@ def configure_rgb_image_randomizer(rgb_shift_limit=40):
     _f_randomize_rgb_image = randomize_rgb_image
 
 
+def configure_gray_image_randomizer():
+
+    def randomize_gray_image(image_arr: np.ndarray):
+        aug_guass = al.GaussNoise(p=1)
+        aug_composed = al.Compose([aug_guass])
+        return aug_composed(image=image_arr)['image']
+
+    global _f_randomize_gray_image
+    _f_randomize_gray_image = randomize_gray_image
+
+
 def configure_depth_image_randomizer(depth_shift_std=0.3, depth_noise_std=0.01):
 
     def randomize_depth_image(image_arr: np.ndarray):
@@ -34,3 +46,4 @@ def configure_depth_image_randomizer(depth_shift_std=0.3, depth_noise_std=0.01):
 
 configure_rgb_image_randomizer()
 configure_depth_image_randomizer()
+configure_gray_image_randomizer()
