@@ -9,7 +9,9 @@ from mohou.model.common import ModelConfigBase
 from mohou.model.common import ModelConfigT
 
 from mohou.model.autoencoder import AutoEncoder
+from mohou.model.autoencoder import AutoEncoderBase
 from mohou.model.autoencoder import AutoEncoderConfig
+from mohou.model.autoencoder import VariationalAutoEncoder
 
 from mohou.model.lstm import LSTM
 from mohou.model.lstm import LSTMConfig
